import 'package:dynamic_widget/dynamic_widget.dart';
import 'package:flutter/material.dart';
import 'package:flutter_form_builder/flutter_form_builder.dart';

import '../layout_form_renderer.dart';
import '../util.dart';

class RadioGroup extends StatefulWidget {
  final Map<String, dynamic> fieldProp;
  final ClickListener? listener;

  RadioGroup({Key? key, required this.fieldProp, required this.listener})
      : super(key: key);

  @override
  _RadioGroupState createState() => _RadioGroupState();
}

class _RadioGroupState extends State<RadioGroup> {
  @override
  Widget build(BuildContext context) {
    Map<String, dynamic> fp = widget.fieldProp;
    String? hint = LayoutForm.getFormFieldPropValue(
        context, fp, LayoutForm.PROP_INPUT_HINT, false);
    String? optStr = LayoutForm.getFormFieldPropValue(
        context, fp, LayoutForm.PROP_OPTIONS, false);

    return Theme(
        data: new ThemeData(
          primaryColor: HexColor.fromHex("#9599B6"),
          primaryColorDark: HexColor.fromHex("#9599B6"),
        ),
        child: Stack(children: [
          FormBuilderRadioGroup(
            validator: (val) {
              return _validate(val, context);
            },
            decoration: InputDecoration(labelText: hint),
            name: fp[LayoutForm.PROP_INPUT_ID],
            options: (optStr == null ? '' : optStr)
                .split("@@@")
                .map((optItem) => FormBuilderFieldOption(value: optItem))
                .toList(),
            onChanged: (val) {},
            separator: const VerticalDivider(
              width: 10,
              thickness: 5,
              color: Colors.transparent,
            ),
          )
        ]));
  }

  String? _validate(dynamic? value, BuildContext context) {
    String? val = value;
    Map<String, dynamic> fp = widget.fieldProp;
    bool? compulsory = LayoutForm.getFormFieldPropValue(
        context, fp, LayoutForm.PROP_COMPULSORY, true);

    if (compulsory != null && compulsory) {
      if (val == null || val.length == 0) {
        return LayoutForm.getFormFieldPropValue(
            context, fp, LayoutForm.PROP_COMPULSORY_ERR_MSG, true);
      }
    }
    return null;
  }
}
